pub fn op_else(cond_stack: &mut ConditionStack) -> boolExpand description
OP_ELSE: Executes the next block of instructions if the previous OP_IF or OP_NOTIF was not executed
Arguments
cond_stack- mutable reference to the condition stack
pub fn op_else(cond_stack: &mut ConditionStack) -> boolOP_ELSE: Executes the next block of instructions if the previous OP_IF or OP_NOTIF was not executed
cond_stack - mutable reference to the condition stack