is_valid_amount

Function is_valid_amount 

pub fn is_valid_amount(_value: &TokenAmount) -> bool
Determines whether the passed value is within bounds of available tokens in the supply.

TODO: Currently placeholder, needs to be filled in once requirements known