pub fn is_valid_amount(_value: &TokenAmount) -> boolExpand description
Determines whether the passed value is within bounds of available tokens in the supply.
TODO: Currently placeholder, needs to be filled in once requirements known
pub fn is_valid_amount(_value: &TokenAmount) -> boolDetermines whether the passed value is within bounds of available tokens in the supply.
TODO: Currently placeholder, needs to be filled in once requirements known